pub fn pack_morph_bundle(
targets: &[MorphTargetExport],
config: &MorphExportConfig,
) -> MorphExportBundleExpand description
Pack a slice of morph targets into an export bundle using the given config.
pub fn pack_morph_bundle(
targets: &[MorphTargetExport],
config: &MorphExportConfig,
) -> MorphExportBundlePack a slice of morph targets into an export bundle using the given config.