pub fn validate_point_cache_file(path: &Path) -> Result<PointCacheHeader>Expand description
Validate a .opc file and return its header without loading frame data.
pub fn validate_point_cache_file(path: &Path) -> Result<PointCacheHeader>Validate a .opc file and return its header without loading frame data.